Module property

Module property 

Property-based testing utilities for Windjammer

Provides simple property-based testing without external dependencies. For more advanced property testing, integrate proptest or quickcheck.

Functions

find_minimal_failing
Find the minimal failing input using shrinking
property_test
Run a property test with random generated inputs
property_test_with_gen
Test a property with a specific generator function
property_test_with_gen1
Alias for property_test_with_gen to match the naming convention of gen2/gen3 This is used by the Windjammer compiler’s code generation
property_test_with_gen2
Test a property with two generated inputs
property_test_with_gen3
Test a property with three generated inputs
shrink_int
Shrink a value to find minimal failing case This is a simplified shrinking strategy