Property-based testing utilities for Windjammer
Provides simple property-based testing without external dependencies. For more advanced property testing, integrate proptest or quickcheck.
Functions
- find_
minimal_ failing - Find the minimal failing input using shrinking
- property_
test - Run a property test with random generated inputs
- property_
test_ with_ gen - Test a property with a specific generator function
- property_
test_ with_ gen1 - Alias for
property_test_with_gento match the naming convention of gen2/gen3 This is used by the Windjammer compiler’s code generation - property_
test_ with_ gen2 - Test a property with two generated inputs
- property_
test_ with_ gen3 - Test a property with three generated inputs
- shrink_
int - Shrink a value to find minimal failing case This is a simplified shrinking strategy